@@ -1,12 +1,21 @@
-import sqlite3
+"""Interaction with SQLite database.
+"""
 import os
-import uuid
+import sqlite3
 import threading
+import uuid
 from datetime import datetime, timedelta
-from typing import List, Tuple, Optional
+from typing import List, Optional, Tuple
+
+from fastapi import HTTPException
+from starlette.status import HTTP_404_NOT_FOUND, HTTP_422_UNPROCESSABLE_ENTITY
 
 
 class SQLiteAccess:
+    """Class handling SQLite connection and writes"""
+
+    # TODO This should not be a class, a fully functional approach is better
+
     def __init__(self):
         try:
             self.db_location = os.environ["FASTAPI_SIMPLE_SECURITY_DB_LOCATION"]
@@ -25,6 +34,7 @@ class SQLiteAccess:
     def init_db(self):
         with sqlite3.connect(self.db_location) as connection:
             c = connection.cursor()
+            # Create database
             c.execute(
                 """
         CREATE TABLE IF NOT EXISTS fastapi_simple_security (
@@ -37,17 +47,24 @@ class SQLiteAccess:
         """
             )
             connection.commit()
+            # Migration: Add api key name
+            try:
+                c.execute("ALTER TABLE fastapi_simple_security ADD COLUMN name TEXT")
+                connection.commit()
+            except sqlite3.OperationalError:
+                pass  # Column already exist
 
-    def create_key(self, never_expire) -> str:
+    def create_key(self, name, never_expire) -> str:
         api_key = str(uuid.uuid4())
 
         with sqlite3.connect(self.db_location) as connection:
             c = connection.cursor()
             c.execute(
                 """
-                INSERT INTO fastapi_simple_security 
-                (api_key, is_active, never_expire, expiration_date, latest_query_date, total_queries) 
-                VALUES(?, ?, ?, ?, ?, ?)
+                INSERT INTO fastapi_simple_security
+                (api_key, is_active, never_expire, expiration_date, \
+                    latest_query_date, total_queries, name)
+                VALUES(?, ?, ?, ?, ?, ?, ?)
             """,
                 (
                     api_key,
@@ -58,6 +75,7 @@ class SQLiteAccess:
                     ).isoformat(timespec="seconds"),
                     None,
                     0,
+                    name,
                 ),
             )
             connection.commit()
@@ -72,7 +90,7 @@ class SQLiteAccess:
             c.execute(
                 """
             SELECT is_active, total_queries, expiration_date, never_expire
-            FROM fastapi_simple_security 
+            FROM fastapi_simple_security
             WHERE api_key = ?""",
                 (api_key,),
             )
@@ -81,7 +99,9 @@ class SQLiteAccess:
 
             # API key not found
             if not response:
-                return "API key not found"
+                raise HTTPException(
+                    status_code=HTTP_404_NOT_FOUND, detail="API key not found"
+                )
 
             response_lines = []
 
@@ -90,26 +110,25 @@ class SQLiteAccess:
                 response_lines.append(
                     "This API key was revoked and has been reactivated."
                 )
-            # Expired key. Issue a text warning and reactivate it.
-            if (not response[3]) and (
-                datetime.fromisoformat(response[2]) < datetime.utcnow()
-            ):
-                response_lines.append("This API key was expired and is now renewed.")
 
+            # Without an expiration date, we set it here
             if not new_expiration_date:
                 parsed_expiration_date = (
                     datetime.utcnow() + timedelta(days=self.expiration_limit)
                 ).isoformat(timespec="seconds")
+
             else:
                 try:
                     # We parse and re-write to the right timespec
                     parsed_expiration_date = datetime.fromisoformat(
                         new_expiration_date
                     ).isoformat(timespec="seconds")
-                except ValueError:
-                    return (
-                        "The expiration date could not be parsed. Please use ISO 8601."
-                    )
+                except ValueError as exc:
+                    raise HTTPException(
+                        status_code=HTTP_422_UNPROCESSABLE_ENTITY,
+                        detail="The expiration date could not be parsed. \
+                            Please use ISO 8601.",
+                    ) from exc
 
             c.execute(
                 """
@@ -166,7 +185,7 @@ class SQLiteAccess:
             c.execute(
                 """
             SELECT is_active, total_queries, expiration_date, never_expire
-            FROM fastapi_simple_security 
+            FROM fastapi_simple_security
             WHERE api_key = ?""",
                 (api_key,),
             )
@@ -205,7 +224,8 @@ class SQLiteAccess:
         with sqlite3.connect(self.db_location) as connection:
             c = connection.cursor()
 
-            # If we get there, this means it’s an active API key that’s in the database. We update the table.
+            # If we get there, this means it’s an active API key that’s in the database.\
+            #   We update the table.
             c.execute(
                 """
             UPDATE fastapi_simple_security
@@ -221,19 +241,21 @@ class SQLiteAccess:
 
             connection.commit()
 
-    def get_usage_stats(self) -> List[Tuple[str, int, str, str, int]]:
+    def get_usage_stats(self) -> List[Tuple[str, bool, bool, str, str, int]]:
         """
         Returns usage stats for all API keys
 
         Returns:
-            a list of tuples with values being api_key, is_active, expiration_date, latest_query_date, and total_queries
+            a list of tuples with values being api_key, is_active, expiration_date, \
+                latest_query_date, and total_queries
         """
         with sqlite3.connect(self.db_location) as connection:
             c = connection.cursor()
 
             c.execute(
                 """
-            SELECT api_key, is_active, never_expire, expiration_date, latest_query_date, total_queries 
+            SELECT api_key, is_active, never_expire, expiration_date, \
+                latest_query_date, total_queries, name
             FROM fastapi_simple_security
             ORDER BY latest_query_date DESC
             """,
